@@ -46,7 +46,7 @@ def blur(inputimage, outputimage, radius, opacity):
     datas = bluredimage.getdata()
     newData = []
     for item in datas:
-        newData.append([item[0], item[1], item[2], opacity*item[3]])
+        newData.append([item[0], item[1], item[2], int(opacity*item[3])])
 
     bluredimage.putdata(newData)
     
