@@ -6,6 +6,7 @@ import click
 from .removebg import removebg
 from .pixelate import pixelate
 from .blur import blur
+from .stack import stack
 
 CONTEXT_SETTINGS = dict(
         help_option_names = [
@@ -18,6 +19,7 @@ CONTEXT_SETTINGS = dict(
 def main():
     pass
 
+main.add_command(stack)
 main.add_command(blur)
 main.add_command(pixelate)
 main.add_command(removebg)
